/****************************************************************************
 * This file is part of the project AqFinance.
 * AqFinance (c) by 2011 Martin Preuss, all rights reserved.
 *
 * The license for this file can be found in the file COPYING which you
 * should have received along with this file.
 ****************************************************************************/


#ifndef AF_REPORT_AXIS_FNS_H
#define AF_REPORT_AXIS_FNS_H


#ifdef __cplusplus
extern "C" {
#endif


/**
 * Adds markings for every day within the range of the given axis.
 * For this to be usefull the data type for the given axis should be
 * @ref AF_Report_DataType_Date.
 * @param ax axis to add marks for
 * @param level level of the markings to be created (1-n)
 * @param dateTempl template for the marking labels for @ref GWEN_Date_toStringWithTemplate()
 * @param colorWD color for working day marks
 * @param colorWE color for weekend day marks
 */
AE_API void AF_Report_Axis_AddTicksForDays(AF_REPORT_AXIS *ax, int level, uint32_t flags, const char *dateTempl,
                                           int colorWD, int colorWE);

AE_API void AF_Report_Axis_AddTicksForWeeks(AF_REPORT_AXIS *ax, int level, uint32_t flags, int color,
                                            int weekStartsSunday);
AE_API void AF_Report_Axis_AddTicksForMonths(AF_REPORT_AXIS *ax, int level, uint32_t flags, int color,
                                             const char *dateTempl);
AE_API void AF_Report_Axis_AddTicksForYears(AF_REPORT_AXIS *ax, int level, uint32_t flags, int color,
                                            const char *dateTempl);

AE_API void AF_Report_Axis_AddTicksForInt(AF_REPORT_AXIS *ax, int level, uint32_t flags, int color, int step);
AE_API void AF_Report_Axis_AddTicksForDouble(AF_REPORT_AXIS *ax, int level, uint32_t flags, int color, double step,
                                             int prec);



#ifdef __cplusplus
}
#endif


#endif

